import React from 'react';
import { render, screen, fireEvent } from '@testing-library/react';
import { axe } from 'jest-axe';
import Button from '@/components/common/Button';

describe('Button component', () => {
  it('renders correctly with default props', () => {
    render(<Button>Click me</Button>);
    
    const button = screen.getByRole('button', { name: /Click me/i });
    expect(button).toBeInTheDocument();
    expect(button).toHaveClass('button--primary'); // Default variant
    expect(button).toHaveClass('button--md'); // Default size
  });
  
  it('renders a link when href is provided', () => {
    render(<Button href="/test">Click me</Button>);
    
    const link = screen.getByRole('link', { name: /Click me/i });
    expect(link).toBeInTheDocument();
    expect(link).toHaveAttribute('href', '/test');
  });
  
  it('applies disabled state properly', () => {
    render(<Button disabled>Click me</Button>);
    
    const button = screen.getByRole('button', { name: /Click me/i });
    expect(button).toBeDisabled();
    expect(button).toHaveAttribute('aria-disabled', 'true');
  });
  
  it('applies loading state correctly', () => {
    render(<Button loading>Click me</Button>);
    
    const button = screen.getByRole('button', { name: /Click me/i });
    expect(button).toBeDisabled();
    const loader = button.querySelector('.buttonLoader');
    expect(loader).toBeInTheDocument();
  });
  
  it('handles click events', () => {
    const handleClick = jest.fn();
    render(<Button onClick={handleClick}>Click me</Button>);
    
    const button = screen.getByRole('button', { name: /Click me/i });
    fireEvent.click(button);
    
    expect(handleClick).toHaveBeenCalledTimes(1);
  });
  
  it('renders with an icon', () => {
    const mockIcon = <span data-testid="mock-icon">icon</span>;
    render(<Button icon={mockIcon}>Click me</Button>);
    
    const icon = screen.getByTestId('mock-icon');
    expect(icon).toBeInTheDocument();
  });
  
  it('applies custom className', () => {
    render(<Button className="custom-class">Click me</Button>);
    
    const button = screen.getByRole('button', { name: /Click me/i });
    expect(button).toHaveClass('custom-class');
  });
  
  it('has no accessibility violations', async () => {
    const { container } = render(<Button>Click me</Button>);
    const results = await axe(container);
    expect(results).toHaveNoViolations();
  });
  
  it('applies correct aria attributes', () => {
    render(
      <Button
        ariaLabel="Custom label"
        ariaExpanded={true}
        ariaControls="dropdown-menu"
      >
        Menu
      </Button>
    );
    
    const button = screen.getByRole('button', { name: /Custom label/i });
    expect(button).toHaveAttribute('aria-expanded', 'true');
    expect(button).toHaveAttribute('aria-controls', 'dropdown-menu');
  });
});